@@ -7,10 +7,16 @@ import secrets
 
 import pytest
 
+import structlog
+
 from structlog.contextvars import (
+    _CONTEXT_VARS,
     bind_contextvars,
     clear_contextvars,
+    get_contextvars,
+    get_merged_contextvars,
     merge_contextvars,
+    reset_contextvars,
     unbind_contextvars,
 )
 
@@ -19,7 +25,15 @@ from structlog.contextvars import (
 pytestmark = pytest.mark.asyncio
 
 
-class TestNewContextvars:
+@pytest.fixture(autouse=True)
+def _clear_contextvars():
+    """
+    Make sure all tests start with a clean slate.
+    """
+    clear_contextvars()
+
+
+class TestContextvars:
     async def test_bind(self, event_loop):
         """
         Binding a variable causes it to be included in the result of
@@ -50,6 +64,30 @@ class TestNewContextvars:
             "d": 4,
         } == await event_loop.create_task(coro())
 
+    async def test_reset(self, event_loop):
+        """
+        reset_contextvars allows resetting contexvars to
+        previously-set values.
+        """
+
+        async def coro():
+            bind_contextvars(a=1)
+
+            assert {"a": 1} == get_contextvars()
+
+            await event_loop.create_task(nested_coro())
+
+        async def nested_coro():
+            tokens = bind_contextvars(a=2, b=3)
+
+            assert {"a": 2, "b": 3} == get_contextvars()
+
+            reset_contextvars(**tokens)
+
+            assert {"a": 1} == get_contextvars()
+
+        await event_loop.create_task(coro())
+
     async def test_nested_async_bind(self, event_loop):
         """
         Context is passed correctly between "nested" concurrent operations.
@@ -145,7 +183,6 @@ class TestNewContextvars:
         Binding a variable causes it to be included in the result of
         merge_contextvars.
         """
-
         coro1_bind = asyncio.Event()
         coro2_bind = asyncio.Event()
 
@@ -172,3 +209,23 @@ class TestNewContextvars:
 
         assert {"a": 1, "b": 2, "c": 3} == await coro1_task
         assert {"a": 2, "b": 2, "c": 3} == await coro2_task
+
+    def test_get_only_gets_structlog_without_deleted(self):
+        """
+        get_contextvars returns only the structlog-specific key/values with the
+        prefix removed. Deleted keys (= Ellipsis) are ignored.
+        """
+        bind_contextvars(a=1, b=2)
+        unbind_contextvars("b")
+        _CONTEXT_VARS["foo"] = "bar"
+
+        assert {"a": 1} == get_contextvars()
+
+    def test_get_merged_merges_context(self):
+        """
+        get_merged_contextvars merges a bound context into the copy.
+        """
+        bind_contextvars(x=1)
+        log = structlog.get_logger().bind(y=2)
+
+        assert {"x": 1, "y": 2} == get_merged_contextvars(log)
